@@ -35,7 +35,13 @@ VECTOR_MODELS = {
         CorporaEnum.RNC_WIKIPEDIA: {
             VectorModelType.WORD2VEC: Word2Vec
         }
-    }
+    },
+    Lang.FR: {
+        CorporaEnum.LE_MONDE: {
+            VectorModelType.WORD2VEC: Word2Vec
+        }
+    },
+    
 }
 
 DEFAULT_MODELS = {
